# Muay Thai Combinations

A really simple app that will display Muay Thai Combinations for use in shadow boxing

The user can choose whether to only include low round-house kicks or have no round-house kicks at all

Some recommended combinations are coded in or the user can choose to create random combinations from single attacks